@@ -264,6 +264,11 @@ get_box.sf <- function( data, l ) {
 	return( jsonify::to_json( bbox ) )
 }
 
+#' @export
+get_box.interleaved <- function( data, l ) {
+	return( jsonify::to_json( data[["bbox"]] ) )
+}
+
 #' @export
 get_box.data.frame <- function( data, l ) {
 
