@@ -3,8 +3,20 @@
 #' Retrieves the mapdeck token that has been set
 #'
 #' @export
-mapdeck_tokens <- function() getOption("mapdeck")
+mapdeck_tokens <- function() {
 
+	if(!is.na( getOption("mapdeck")[["mapdeck"]][["mapbox"]] ) ) {
+		return( getOption("mapdeck") )
+	}
+
+	if( !is.null( get_access_token() ) ){
+		return( get_access_token() )
+	}
+
+	cat("no tokens found")
+	return(invisible())
+
+}
 
 #' @export
 print.mapdeck_api <- function(x, ...) {
@@ -64,10 +76,17 @@ clear_tokens <- function() {
 
 get_access_token <- function(api = "mapbox") {
 
-	## try and find specific key,
-	## then go for the general one
 	api <- getOption("mapdeck")[['mapdeck']][[api]]
-	# if(is.null(api) || is.na(api)) message("No access token supplied. Use either the 'token' parameter, or use `set_token()`")
-	return(api)
+	if( is.null( api ) || is.na( api ) ) {
+		e <- Sys.getenv()
+		e <- e[ grep( "mapbox|mapdeck", names( e ), ignore.case = TRUE ) ]
+
+		api <- unique( as.character( e ) )
+		if( length( api ) > 1 ) {
+			warning("Multiple MAPBOX API tokens found in Sys.getenv(), using the first one")
+		}
+	}
+	if(length(api) == 0) api <- NULL
+	return(api[1L])
 }
 
