@@ -40,3 +40,10 @@ test_that("add_screengrid accepts multiple objects", {
 	expect_equal( as.character( p$x$calls[[1]]$args[[2]] ), geo )
 
 })
+
+test_that("empty data doesn't crash",{
+	## issue 252
+	m <- mapdeck()
+	res <- mapdeck::add_screengrid(map = m, data = data.frame())
+	expect_true( res$x$calls[[1]]$functions == "md_layer_clear" )
+})
